==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/hu/chinese.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ez a negyedév",
	"field-quarter-short-relative+1": "következő negyedév",
	"field-tue-relative+-1": "előző kedd",
	"field-year": "év",
	"field-wed-relative+0": "ez a szerda",
	"field-wed-relative+1": "következő szerda",
	"field-minute": "perc",
	"field-month-narrow-relative+-1": "előző hónap",
	"field-tue-narrow-relative+0": "ez a kedd",
	"field-tue-narrow-relative+1": "következő kedd",
	"field-thu-short-relative+0": "ez a csütörtök",
	"field-day-short-relative+-1": "tegnap",
	"field-thu-short-relative+1": "következő csütörtök",
	"field-day-relative+0": "ma",
	"field-day-short-relative+-2": "tegnapelőtt",
	"field-day-relative+1": "holnap",
	"field-week-narrow-relative+0": "ez a hét",
	"field-day-relative+2": "holnapután",
	"field-week-narrow-relative+1": "következő hét",
	"field-wed-narrow-relative+-1": "előző szerda",
	"field-year-narrow": "év",
	"field-year-narrow-relative+0": "ez az év",
	"field-tue-relative+0": "ez a kedd",
	"field-year-narrow-relative+1": "következő év",
	"field-tue-relative+1": "következő kedd",
	"field-second-short": "másodperc",
	"field-week-relative+0": "ez a hét",
	"field-month-relative+0": "ez a hónap",
	"field-week-relative+1": "következő hét",
	"field-month-relative+1": "következő hónap",
	"field-sun-narrow-relative+0": "ez a vasárnap",
	"field-mon-short-relative+0": "ez a hétfő",
	"field-sun-narrow-relative+1": "következő vasárnap",
	"field-mon-short-relative+1": "következő hétfő",
	"field-second-relative+0": "most",
	"field-month-short": "hónap",
	"field-day": "nap",
	"field-year-relative+-1": "előző év",
	"field-sat-short-relative+-1": "előző szombat",
	"field-hour-relative+0": "ebben az órában",
	"field-wed-relative+-1": "előző szerda",
	"field-sat-narrow-relative+-1": "előző szombat",
	"field-second": "másodperc",
	"field-quarter": "negyedév",
	"field-week-short": "hét",
	"field-day-narrow-relative+0": "ma",
	"field-day-narrow-relative+1": "holnap",
	"field-day-narrow-relative+2": "holnapután",
	"field-tue-short-relative+0": "ez a kedd",
	"field-tue-short-relative+1": "következő kedd",
	"field-month-short-relative+-1": "előző hónap",
	"field-mon-relative+-1": "előző hétfő",
	"field-month": "hónap",
	"field-day-narrow": "nap",
	"field-minute-short": "perc",
	"field-dayperiod": "napszak",
	"field-sat-short-relative+0": "ez a szombat",
	"field-sat-short-relative+1": "következő szombat",
	"field-second-narrow": "másodperc",
	"field-mon-relative+0": "ez a hétfő",
	"field-mon-relative+1": "következő hétfő",
	"field-day-narrow-relative+-1": "tegnap",
	"field-year-short": "év",
	"field-day-narrow-relative+-2": "tegnapelőtt",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "előző negyedév",
	"field-week-narrow-relative+-1": "előző hét",
	"field-sat-relative+-1": "előző szombat",
	"field-hour": "óra",
	"field-month-relative+-1": "előző hónap",
	"field-quarter-short": "negyedév",
	"field-sat-narrow-relative+0": "ez a szombat",
	"field-fri-relative+0": "ez a péntek",
	"field-sat-narrow-relative+1": "következő szombat",
	"field-fri-relative+1": "következő péntek",
	"field-month-narrow-relative+0": "ez a hónap",
	"field-month-narrow-relative+1": "következő hónap",
	"field-sun-short-relative+0": "ez a vasárnap",
	"field-sun-short-relative+1": "következő vasárnap",
	"field-week-relative+-1": "előző hét",
	"field-quarter-short-relative+-1": "előző negyedév",
	"months-format-abbr": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+0": "ez a negyedév",
	"field-minute-relative+0": "ebben a percben",
	"field-quarter-relative+1": "következő negyedév",
	"field-wed-short-relative+-1": "előző szerda",
	"field-thu-short-relative+-1": "előző csütörtök",
	"field-year-narrow-relative+-1": "előző év",
	"field-mon-narrow-relative+-1": "előző hétfő",
	"field-thu-narrow-relative+-1": "előző csütörtök",
	"field-tue-narrow-relative+-1": "előző kedd",
	"field-wed-short-relative+0": "ez a szerda",
	"months-standAlone-wide": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-wed-short-relative+1": "következő szerda",
	"field-sun-relative+-1": "előző vasárnap",
	"field-weekday": "hét napja",
	"field-day-short-relative+0": "ma",
	"field-quarter-narrow-relative+0": "ez a negyedév",
	"field-sat-relative+0": "ez a szombat",
	"field-day-short-relative+1": "holnap",
	"field-quarter-narrow-relative+1": "következő negyedév",
	"field-sat-relative+1": "következő szombat",
	"field-day-short-relative+2": "holnapután",
	"field-week-short-relative+0": "ez a hét",
	"field-week-short-relative+1": "következő hét",
	"months-standAlone-abbr": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-month-short-relative+0": "ez a hónap",
	"field-month-short-relative+1": "következő hónap",
	"field-thu-narrow-relative+0": "ez a csütörtök",
	"field-thu-narrow-relative+1": "következő csütörtök",
	"field-sun-narrow-relative+-1": "előző vasárnap",
	"field-mon-short-relative+-1": "előző hétfő",
	"field-thu-relative+0": "ez a csütörtök",
	"field-thu-relative+1": "következő csütörtök",
	"field-fri-short-relative+-1": "előző péntek",
	"field-thu-relative+-1": "előző csütörtök",
	"field-week": "hét",
	"field-wed-narrow-relative+0": "ez a szerda",
	"field-wed-narrow-relative+1": "következő szerda",
	"field-quarter-narrow-relative+-1": "előző negyedév",
	"field-year-short-relative+0": "ez az év",
	"field-year-short-relative+1": "következő év",
	"field-fri-short-relative+0": "ez a péntek",
	"field-fri-short-relative+1": "következő péntek",
	"field-week-short-relative+-1": "előző hét",
	"field-hour-short": "óra",
	"field-month-narrow": "hónap",
	"field-hour-narrow": "óra",
	"field-fri-narrow-relative+-1": "előző péntek",
	"field-year-relative+0": "ez az év",
	"field-year-relative+1": "következő év",
	"field-fri-relative+-1": "előző péntek",
	"field-tue-short-relative+-1": "előző kedd",
	"field-minute-narrow": "perc",
	"field-mon-narrow-relative+0": "ez a hétfő",
	"field-mon-narrow-relative+1": "következő hétfő",
	"field-year-short-relative+-1": "előző év",
	"field-zone": "időzóna",
	"field-quarter-narrow": "negyedév",
	"field-sun-short-relative+-1": "előző vasárnap",
	"field-day-relative+-1": "tegnap",
	"field-day-relative+-2": "tegnapelőtt",
	"field-sun-relative+0": "ez a vasárnap",
	"field-sun-relative+1": "következő vasárnap",
	"field-day-short": "nap",
	"field-week-narrow": "hét",
	"field-era": "éra",
	"field-fri-narrow-relative+0": "ez a péntek",
	"field-fri-narrow-relative+1": "következő péntek"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/hu/chinese.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ez a negyedév",
	"field-quarter-short-relative+1": "következő negyedév",
	"field-tue-relative+-1": "előző kedd",
	"field-year": "év",
	"field-wed-relative+0": "ez a szerda",
	"field-wed-relative+1": "következő szerda",
	"field-minute": "perc",
	"field-month-narrow-relative+-1": "előző hónap",
	"field-tue-narrow-relative+0": "ez a kedd",
	"field-tue-narrow-relative+1": "következő kedd",
	"field-thu-short-relative+0": "ez a csütörtök",
	"field-day-short-relative+-1": "tegnap",
	"field-thu-short-relative+1": "következő csütörtök",
	"field-day-relative+0": "ma",
	"field-day-short-relative+-2": "tegnapelőtt",
	"field-day-relative+1": "holnap",
	"field-week-narrow-relative+0": "ez a hét",
	"field-day-relative+2": "holnapután",
	"field-week-narrow-relative+1": "következő hét",
	"field-wed-narrow-relative+-1": "előző szerda",
	"field-year-narrow": "év",
	"field-era-short": "éra",
	"field-year-narrow-relative+0": "ez az év",
	"field-tue-relative+0": "ez a kedd",
	"field-year-narrow-relative+1": "következő év",
	"field-tue-relative+1": "következő kedd",
	"field-weekdayOfMonth": "hónap hétköznapja",
	"field-second-short": "másodperc",
	"field-weekdayOfMonth-narrow": "hónap hétköznapja",
	"field-week-relative+0": "ez a hét",
	"field-month-relative+0": "ez a hónap",
	"field-week-relative+1": "következő hét",
	"field-month-relative+1": "következő hónap",
	"field-sun-narrow-relative+0": "ez a vasárnap",
	"field-mon-short-relative+0": "ez a hétfő",
	"field-sun-narrow-relative+1": "következő vasárnap",
	"field-mon-short-relative+1": "következő hétfő",
	"field-second-relative+0": "most",
	"field-weekOfMonth": "hónap hete",
	"field-month-short": "hónap",
	"field-day": "nap",
	"field-dayOfYear-short": "év napja",
	"field-year-relative+-1": "előző év",
	"field-sat-short-relative+-1": "előző szombat",
	"field-hour-relative+0": "ebben az órában",
	"field-wed-relative+-1": "előző szerda",
	"field-sat-narrow-relative+-1": "előző szombat",
	"field-second": "másodperc",
	"field-quarter": "negyedév",
	"field-week-short": "hét",
	"field-day-narrow-relative+0": "ma",
	"field-day-narrow-relative+1": "holnap",
	"field-day-narrow-relative+2": "holnapután",
	"field-tue-short-relative+0": "ez a kedd",
	"field-tue-short-relative+1": "következő kedd",
	"field-month-short-relative+-1": "előző hónap",
	"field-mon-relative+-1": "előző hétfő",
	"field-month": "hónap",
	"field-day-narrow": "nap",
	"field-minute-short": "perc",
	"field-dayperiod": "napszak",
	"field-sat-short-relative+0": "ez a szombat",
	"field-sat-short-relative+1": "következő szombat",
	"field-second-narrow": "mp",
	"field-mon-relative+0": "ez a hétfő",
	"field-mon-relative+1": "következő hétfő",
	"field-day-narrow-relative+-1": "tegnap",
	"field-year-short": "év",
	"field-day-narrow-relative+-2": "tegnapelőtt",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "előző negyedév",
	"field-dayperiod-narrow": "napszak",
	"field-week-narrow-relative+-1": "előző hét",
	"field-dayOfYear": "év napja",
	"field-sat-relative+-1": "előző szombat",
	"field-hour": "óra",
	"field-month-relative+-1": "előző hónap",
	"field-quarter-short": "n.év",
	"field-sat-narrow-relative+0": "ez a szombat",
	"field-fri-relative+0": "ez a péntek",
	"field-sat-narrow-relative+1": "következő szombat",
	"field-fri-relative+1": "következő péntek",
	"field-month-narrow-relative+0": "ez a hónap",
	"field-month-narrow-relative+1": "következő hónap",
	"field-sun-short-relative+0": "ez a vasárnap",
	"field-sun-short-relative+1": "következő vasárnap",
	"field-week-relative+-1": "előző hét",
	"field-quarter-short-relative+-1": "előző negyedév",
	"months-format-abbr": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+0": "ez a negyedév",
	"field-minute-relative+0": "ebben a percben",
	"field-quarter-relative+1": "következő negyedév",
	"field-wed-short-relative+-1": "előző szerda",
	"field-thu-short-relative+-1": "előző csütörtök",
	"field-year-narrow-relative+-1": "előző év",
	"field-mon-narrow-relative+-1": "előző hétfő",
	"field-thu-narrow-relative+-1": "előző csütörtök",
	"field-tue-narrow-relative+-1": "előző kedd",
	"field-weekOfMonth-short": "hónap hete",
	"field-wed-short-relative+0": "ez a szerda",
	"months-standAlone-wide": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-wed-short-relative+1": "következő szerda",
	"field-sun-relative+-1": "előző vasárnap",
	"field-weekday": "hét napja",
	"field-day-short-relative+0": "ma",
	"field-quarter-narrow-relative+0": "ez a negyedév",
	"field-sat-relative+0": "ez a szombat",
	"field-day-short-relative+1": "holnap",
	"field-quarter-narrow-relative+1": "következő negyedév",
	"field-sat-relative+1": "következő szombat",
	"field-day-short-relative+2": "holnapután",
	"field-week-short-relative+0": "ez a hét",
	"field-week-short-relative+1": "következő hét",
	"months-standAlone-abbr": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-dayOfYear-narrow": "év napja",
	"field-month-short-relative+0": "ez a hónap",
	"field-month-short-relative+1": "következő hónap",
	"field-weekdayOfMonth-short": "hónap hétköznapja",
	"field-zone-narrow": "időzóna",
	"field-thu-narrow-relative+0": "ez a csütörtök",
	"field-thu-narrow-relative+1": "következő csütörtök",
	"field-sun-narrow-relative+-1": "előző vasárnap",
	"field-mon-short-relative+-1": "előző hétfő",
	"field-thu-relative+0": "ez a csütörtök",
	"field-thu-relative+1": "következő csütörtök",
	"field-fri-short-relative+-1": "előző péntek",
	"field-thu-relative+-1": "előző csütörtök",
	"field-week": "hét",
	"field-wed-narrow-relative+0": "ez a szerda",
	"field-wed-narrow-relative+1": "következő szerda",
	"field-quarter-narrow-relative+-1": "előző negyedév",
	"field-year-short-relative+0": "ez az év",
	"field-dayperiod-short": "napszak",
	"field-year-short-relative+1": "következő év",
	"field-fri-short-relative+0": "ez a péntek",
	"field-fri-short-relative+1": "következő péntek",
	"field-week-short-relative+-1": "előző hét",
	"field-hour-short": "óra",
	"field-zone-short": "időzóna",
	"field-month-narrow": "hónap",
	"field-hour-narrow": "ó",
	"field-fri-narrow-relative+-1": "előző péntek",
	"field-year-relative+0": "ez az év",
	"field-year-relative+1": "következő év",
	"field-era-narrow": "éra",
	"field-fri-relative+-1": "előző péntek",
	"field-tue-short-relative+-1": "előző kedd",
	"field-minute-narrow": "p",
	"field-mon-narrow-relative+0": "ez a hétfő",
	"field-mon-narrow-relative+1": "következő hétfő",
	"field-year-short-relative+-1": "előző év",
	"field-zone": "időzóna",
	"field-weekOfMonth-narrow": "hónap hete",
	"field-weekday-narrow": "hét napja",
	"field-quarter-narrow": "n.év",
	"field-sun-short-relative+-1": "előző vasárnap",
	"field-day-relative+-1": "tegnap",
	"field-day-relative+-2": "tegnapelőtt",
	"field-weekday-short": "hét napja",
	"field-sun-relative+0": "ez a vasárnap",
	"field-sun-relative+1": "következő vasárnap",
	"field-day-short": "nap",
	"field-week-narrow": "hét",
	"field-era": "éra",
	"field-fri-narrow-relative+0": "ez a péntek",
	"field-fri-narrow-relative+1": "következő péntek"
}
//end v1.x content
);
